## 🐛 Bug Reports

When reporting a bug, please provide the following information. If this is not a bug report you can just discard this template.

### 🌍 Environment

 - Your operating system and version:
 - Your python version:
 - How did you install python (e.g. apt or pyenv)? Did you use a virtualenv?:
 - Your Rust version (`rustc --version`):
 - Your PyO3 version:
 - Have you tried using latest PyO3 master (replace `version = "0.x.y"` with `git = "https://github.com/awestlake87/pyo3-asyncio")?`:

### 💥 Reproducing

Please provide a [minimal working example](https://stackoverflow.com/help/mcve). This means both the Rust code and the Python.

Please also write what exact flags are required to reproduce your results.
